@if "%DEBUG%" == "" @echo off
@rem ##########################################################################
@rem
@rem  xl-license-generator startup script for Windows
@rem
@rem ##########################################################################

@rem Set local scope for the variables with windows NT shell
if "%OS%"=="Windows_NT" setlocal

@rem Add default JVM options here. You can also use JAVA_OPTS and XL_LICENSE_GENERATOR_OPTS to pass JVM options to this script.
set DEFAULT_JVM_OPTS=

set DIRNAME=%~dp0
if "%DIRNAME%" == "" set DIRNAME=.
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%..

@rem Find java.exe
if defined JAVA_HOME goto findJavaFromJavaHome

set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
if "%ERRORLEVEL%" == "0" goto init

echo.
echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:findJavaFromJavaHome
set JAVA_HOME=%JAVA_HOME:"=%
set JAVA_EXE=%JAVA_HOME%/bin/java.exe

if exist "%JAVA_EXE%" goto init

echo.
echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
echo.
echo Please set the JAVA_HOME variable in your environment to match the
echo location of your Java installation.

goto fail

:init
@rem Get command-line arguments, handling Windowz variants

if not "%OS%" == "Windows_NT" goto win9xME_args
if "%@eval[2+2]" == "4" goto 4NT_args

:win9xME_args
@rem Slurp the command line arguments.
set CMD_LINE_ARGS=
set _SKIP=2

:win9xME_args_slurp
if "x%~1" == "x" goto execute

set CMD_LINE_ARGS=%*
goto execute

:4NT_args
@rem Get arguments from the 4NT Shell from JP Software
set CMD_LINE_ARGS=%$

:execute
@rem Setup the command line

set CLASSPATH=%APP_HOME%\lib\xl-license-generator-2015.5.1.jar;%APP_HOME%\lib\slf4j-api-1.7.12.jar;%APP_HOME%\lib\jcl-over-slf4j-1.7.12.jar;%APP_HOME%\lib\log4j-over-slf4j-1.7.12.jar;%APP_HOME%\lib\xl-core-2015.5.1.jar;%APP_HOME%\lib\xl-license-2015.5.1.jar;%APP_HOME%\lib\args4j-2.32.jar;%APP_HOME%\lib\bcprov-jdk15on-1.52.jar;%APP_HOME%\lib\guava-18.0.jar;%APP_HOME%\lib\joda-time-2.7.jar;%APP_HOME%\lib\logback-classic-1.1.3.jar;%APP_HOME%\lib\udm-plugin-api-2015.5.1.jar;%APP_HOME%\lib\engine-spi-2015.5.1.jar;%APP_HOME%\lib\engine-api-2015.5.1.jar;%APP_HOME%\lib\local-booter-2015.5.1.jar;%APP_HOME%\lib\replacer-2015.5.1.jar;%APP_HOME%\lib\truezip-file-7.7.8.jar;%APP_HOME%\lib\truezip-kernel-7.7.8.jar;%APP_HOME%\lib\commons-codec-1.10.jar;%APP_HOME%\lib\javassist-3.17.1-GA.jar;%APP_HOME%\lib\t2-bus-1.2.1.jar;%APP_HOME%\lib\scannit-1.4.0.jar;%APP_HOME%\lib\overthere-4.0.0.jar;%APP_HOME%\lib\spring-context-4.1.6.RELEASE.jar;%APP_HOME%\lib\spring-security-core-4.0.1.RELEASE.jar;%APP_HOME%\lib\spring-beans-4.1.6.RELEASE.jar;%APP_HOME%\lib\jmustache-1.9.jar;%APP_HOME%\lib\commons-httpclient-3.1.jar;%APP_HOME%\lib\scala-library-2.11.6.jar;%APP_HOME%\lib\xl-repository-api-2015.5.1.jar;%APP_HOME%\lib\logback-core-1.1.3.jar;%APP_HOME%\lib\framework-7.1.2.jar;%APP_HOME%\lib\jcr-2.0.jar;%APP_HOME%\lib\jaxrs-api-3.0.11.Final.jar;%APP_HOME%\lib\resteasy-multipart-provider-3.0.11.Final.jar;%APP_HOME%\lib\resteasy-jaxrs-3.0.11.Final.jar;%APP_HOME%\lib\xstream-1.4.8.jar;%APP_HOME%\lib\joda-convert-1.3.jar;%APP_HOME%\lib\commons-lang-2.6.jar;%APP_HOME%\lib\resteasy-jackson-provider-3.0.11.Final.jar;%APP_HOME%\lib\xl-utils-2015.5.1.jar;%APP_HOME%\lib\truezip-driver-file-7.7.8.jar;%APP_HOME%\lib\annotations-3.0.0.jar;%APP_HOME%\lib\truezip-driver-zip-7.7.8.jar;%APP_HOME%\lib\jcifs-1.3.17.jar;%APP_HOME%\lib\dom4j-1.6.1.jar;%APP_HOME%\lib\commons-net-2.0.jar;%APP_HOME%\lib\sshj-0.12.0.jar;%APP_HOME%\lib\jaxen-1.1.6.jar;%APP_HOME%\lib\spring-aop-4.1.6.RELEASE.jar;%APP_HOME%\lib\spring-core-4.1.6.RELEASE.jar;%APP_HOME%\lib\spring-expression-4.1.6.RELEASE.jar;%APP_HOME%\lib\aopalliance-1.0.jar;%APP_HOME%\lib\resteasy-client-3.0.11.Final.jar;%APP_HOME%\lib\resteasy-jaxb-provider-3.0.11.Final.jar;%APP_HOME%\lib\mail-1.5.0-b01.jar;%APP_HOME%\lib\apache-mime4j-0.6.jar;%APP_HOME%\lib\jboss-annotations-api_1.1_spec-1.0.1.Final.jar;%APP_HOME%\lib\activation-1.1.jar;%APP_HOME%\lib\commons-io-2.1.jar;%APP_HOME%\lib\jcip-annotations-1.0.jar;%APP_HOME%\lib\xmlpull-1.1.3.1.jar;%APP_HOME%\lib\xpp3_min-1.1.4c.jar;%APP_HOME%\lib\jackson-core-asl-1.9.12.jar;%APP_HOME%\lib\jackson-mapper-asl-1.9.12.jar;%APP_HOME%\lib\jackson-jaxrs-1.9.12.jar;%APP_HOME%\lib\jackson-xc-1.9.12.jar;%APP_HOME%\lib\scala-reflect-2.11.6.jar;%APP_HOME%\lib\scala-io-core_2.11-0.4.3.jar;%APP_HOME%\lib\scala-io-file_2.11-0.4.3.jar;%APP_HOME%\lib\grizzled-slf4j_2.11-1.0.2.jar;%APP_HOME%\lib\akka-actor_2.11-2.3.9.jar;%APP_HOME%\lib\akka-slf4j_2.11-2.3.9.jar;%APP_HOME%\lib\scala-xml_2.11-1.0.4.jar;%APP_HOME%\lib\bcpkix-jdk15on-1.51.jar;%APP_HOME%\lib\jaxb-impl-2.2.7.jar;%APP_HOME%\lib\scala-parser-combinators_2.11-1.0.1.jar;%APP_HOME%\lib\scala-arm_2.11-1.3.3.jar;%APP_HOME%\lib\config-1.2.1.jar;%APP_HOME%\lib\jaxb-core-2.2.7.jar;%APP_HOME%\lib\FastInfoset-1.2.12.jar;%APP_HOME%\lib\scala-continuations-library_2.11-1.0.1.jar;%APP_HOME%\lib\jaxb-api-2.2.7.jar;%APP_HOME%\lib\istack-commons-runtime-2.16.jar;%APP_HOME%\lib\truezip-swing-7.7.8.jar;%APP_HOME%\lib\commons-compress-1.9.jar;%APP_HOME%\lib\httpclient-4.2.6.jar;%APP_HOME%\lib\jzlib-1.1.3.jar;%APP_HOME%\lib\httpcore-4.2.5.jar

@rem Execute xl-license-generator
"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %XL_LICENSE_GENERATOR_OPTS%  -classpath "%CLASSPATH%" com.xebialabs.license.generator.LicenseGenerator %CMD_LINE_ARGS%

:end
@rem End local scope for the variables with windows NT shell
if "%ERRORLEVEL%"=="0" goto mainEnd

:fail
rem Set variable XL_LICENSE_GENERATOR_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
if  not "" == "%XL_LICENSE_GENERATOR_EXIT_CONSOLE%" exit 1
exit /b 1

:mainEnd
if "%OS%"=="Windows_NT" endlocal

:omega
